@@ -1,15 +1,24 @@
-import spikeextractors as se
 import numpy as np
 from pathlib import Path
+from typing import Optional, Union
+
+import spikeextractors as se
 from .synthesize_random_waveforms import synthesize_random_waveforms
 from .synthesize_random_firings import synthesize_random_firings
 from .synthesize_timeseries import synthesize_timeseries
 
 
-def toy_example(duration=10, num_channels=4, sampling_frequency=30000.0, K=10, dumpable=False, dump_folder=None,
-                seed=None):
+def toy_example(
+    duration: float = 10.,
+    num_channels: int = 4,
+    sampling_frequency: float = 30000.,
+    K: int = 10,
+    dumpable: bool = False,
+    dump_folder: Optional[Union[str, Path]] = None,
+    seed: Optional[int] = None
+):
     """
-    Creates toy recording and sorting extractors.
+    Create toy recording and sorting extractors.
 
     Parameters
     ----------
