@@ -6,7 +6,6 @@ from spikeextractors.extraction_tools import check_get_unit_spike_train, get_sub
 from typing import Union, Optional
 import re
 import warnings
-from typing import Optional
 
 try:
     from lxml import etree as et
@@ -33,6 +32,21 @@ def get_shank_files(folder_path: Path, suffix: str):
         and re.search(r"\d+$", f.name) is not None and len(f.suffixes) == 2
     ]
 
+def find_xml_file_path(folder_path: PathType):
+    xml_files = [f for f in folder_path.iterdir() if f.is_file() if f.suffix == ".xml"]
+    assert any(xml_files), "No .xml files found in the folder_path."
+    assert len(xml_files) == 1, "More than one .xml file found in the folder_path! Specify xml_file_path."
+    xml_file_path = xml_files[0]
+    return xml_file_path
+
+def handle_xml_file_path(folder_path: PathType, initial_xml_file_path: PathType):
+    if initial_xml_file_path is None:
+        xml_file_path = find_xml_file_path(folder_path=folder_path)
+    else:
+        assert Path(initial_xml_file_path).is_file(), f".xml file ({initial_xml_file_path}) not found!"
+        xml_file_path = initial_xml_file_path
+    return xml_file_path
+
 
 class NeuroscopeRecordingExtractor(BinDatRecordingExtractor):
     """
@@ -48,6 +62,8 @@ class NeuroscopeRecordingExtractor(BinDatRecordingExtractor):
         Path to the .dat file to be extracted.
     gain : float, optional
         Numerical value that converts the native int dtype to microvolts. Defaults to 1.
+    xml_file_path : PathType, optional
+        Path to the .xml file referenced by this recording.
     """
 
     extractor_name = "NeuroscopeRecordingExtractor"
@@ -66,17 +82,7 @@ class NeuroscopeRecordingExtractor(BinDatRecordingExtractor):
 
         RecordingExtractor.__init__(self)
         self._recording_file = file_path
-        file_path = Path(file_path)
-        folder_path = file_path.parent
-
-        if xml_file_path is None:
-            xml_files = [f for f in folder_path.iterdir() if f.is_file() if f.suffix == ".xml"]
-            assert any(xml_files), "No .xml files found in the folder_path."
-            assert len(xml_files) == 1, "More than one .xml file found in the folder_path! Specify xml_file_path."
-            xml_file_path = xml_files[0]
-        else:
-            assert Path(xml_file_path).is_file(), f".xml file ({xml_file_path}) not found!"
-
+        xml_file_path = handle_xml_file_path(folder_path=Path(file_path).parent, initial_xml_file_path=xml_file_path)
         xml_root = et.parse(str(xml_file_path)).getroot()
         n_bits = int(xml_root.find('acquisitionSystem').find('nBits').text)
         dtype = f"int{n_bits}"
@@ -178,6 +184,8 @@ class NeuroscopeMultiRecordingTimeExtractor(MultiRecordingTimeExtractor):
         Path to the .dat files to be extracted.
     gain : float, optional
         Numerical value that converts the native int dtype to microvolts. Defaults to 1.
+    xml_file_path : PathType, optional
+        Path to the .xml file referenced by this recording.
     """
 
     extractor_name = "NeuroscopeMultiRecordingTimeExtractor"
@@ -186,14 +194,14 @@ class NeuroscopeMultiRecordingTimeExtractor(MultiRecordingTimeExtractor):
     mode = "folder"
     installation_mesg = "Please install lxml to use this extractor!"
 
-    def __init__(self, folder_path: PathType, gain: Optional[float] = None):
+    def __init__(self, folder_path: PathType, gain: Optional[float] = None, xml_file_path: OptionalPathType = None):
         assert self.installed, self.installation_mesg
 
         folder_path = Path(folder_path)
         recording_files = [x for x in folder_path.iterdir() if x.is_file() and x.suffix == ".dat"]
         assert any(recording_files), "The folder_path must lead to at least one .dat file!"
 
-        recordings = [NeuroscopeRecordingExtractor(file_path=x, gain=gain) for x in recording_files]
+        recordings = [NeuroscopeRecordingExtractor(file_path=x, gain=gain, xml_file_path=xml_file_path) for x in recording_files]
         MultiRecordingTimeExtractor.__init__(self, recordings=recordings)
 
         self._kwargs = dict(folder_path=str(folder_path.absolute()), gain=gain)
@@ -324,6 +332,8 @@ class NeuroscopeSortingExtractor(SortingExtractor):
         Optional. Path to a particular .spk binary file containing waveform snippets added to the extractor as features.
     gain : float
         Optional. If passing a spkfile_path, this value converts the data type of the waveforms to units of microvolts.
+    xml_file_path : PathType, optional
+        Path to the .xml file referenced by this sorting.
     """
 
     extractor_name = "NeuroscopeSortingExtractor"
@@ -339,7 +349,8 @@ class NeuroscopeSortingExtractor(SortingExtractor):
         folder_path: OptionalPathType = None,
         keep_mua_units: bool = True,
         spkfile_path: OptionalPathType = None,
-        gain: Optional[float] = None
+        gain: Optional[float] = None,
+        xml_file_path: OptionalPathType = None,
     ):
         assert self.installed, self.installation_mesg
         assert not (folder_path is None and resfile_path is None and clufile_path is None), \
@@ -382,12 +393,8 @@ class NeuroscopeSortingExtractor(SortingExtractor):
         assert res_sorting_name == clu_sorting_name, "The .res and .clu files do not share the same name! " \
                                                      f"{res_sorting_name}  -- {clu_sorting_name}"
 
-        xml_files = [f for f in folder_path.iterdir() if f.is_file() if f.suffix == ".xml"]
-        assert len(xml_files) > 0, "No .xml file found in the folder!"
-        assert len(xml_files) == 1, "More than one .xml file found in the folder!"
-        xml_filepath = xml_files[0]
-
-        xml_root = et.parse(str(xml_filepath)).getroot()
+        xml_file_path = handle_xml_file_path(folder_path=folder_path, initial_xml_file_path=xml_file_path)
+        xml_root = et.parse(str(xml_file_path)).getroot()
         self._sampling_frequency = float(xml_root.find('acquisitionSystem').find('samplingRate').text)
 
         with open(resfile_path) as f:
@@ -401,22 +408,19 @@ class NeuroscopeSortingExtractor(SortingExtractor):
             n_clu = clu[0]
             clu = np.delete(clu, 0)
             unique_ids = np.unique(clu)
-            if 0 not in unique_ids:  # missing unsorted IDs
-                n_clu += 1
-            if 1 not in unique_ids:  # missing mua IDs
-                n_clu += 1
+            assert len(unique_ids) == n_clu, (
+                "First value of .clu file ({clufile_path}) does not match number of unique IDs!"
+            )
+            unit_map = dict(zip(unique_ids, list(range(1, n_clu + 1))))
 
+            if 0 in unique_ids:
+                unit_map.pop(0)
+            if not keep_mua_units and 1 in unique_ids:
+                unit_map.pop(1)
+            self._unit_ids = unit_map.values()
             self._spiketrains = []
-            if keep_mua_units:
-                n_clu -= 1
-                self._unit_ids = [x + 1 for x in range(n_clu)]  # from 1,...,clu[0]-1
-                for s_id in self._unit_ids:
-                    self._spiketrains.append(res[(clu == s_id).nonzero()])
-            else:
-                n_clu -= 2
-                self._unit_ids = [x + 1 for x in range(n_clu)]  # from 1,...,clu[0]-2
-                for s_id in self._unit_ids:
-                    self._spiketrains.append(res[(clu == s_id + 1).nonzero()])  # from 2,...,clu[0]-1
+            for s_id in unit_map:
+                self._spiketrains.append(res[(clu == s_id).nonzero()])
 
         if spkfile_path is not None and Path(spkfile_path).is_file():
             n_bits = int(xml_root.find('acquisitionSystem').find('nBits').text)
@@ -549,6 +553,8 @@ class NeuroscopeMultiSortingExtractor(MultiSortingExtractor):
         the .res.%i and .clue.%i files and sets these as unit spike features. Defaults to False.
     gain : float
         Optional. If passing a spkfile_path, this value converts the data type of the waveforms to units of microvolts.
+    xml_file_path : PathType, optional
+        Path to the .xml file referenced by this sorting.
     """
 
     extractor_name = "NeuroscopeMultiSortingExtractor"
@@ -563,7 +569,8 @@ class NeuroscopeMultiSortingExtractor(MultiSortingExtractor):
         keep_mua_units: bool = True,
         exclude_shanks: Optional[list] = None,
         load_waveforms: bool = False,
-        gain: Optional[float] = None
+        gain: Optional[float] = None,
+        xml_file_path: OptionalPathType = None,
     ):
         assert self.installed, self.installation_mesg
 
@@ -576,12 +583,8 @@ class NeuroscopeMultiSortingExtractor(MultiSortingExtractor):
         else:
             exclude_shanks = []
             exclude_shanks_passed = False
-        xml_files = [f for f in folder_path.iterdir() if f.is_file if f.suffix == ".xml"]
-        assert len(xml_files) > 0, "No .xml file found in the folder!"
-        assert len(xml_files) == 1, "More than one .xml file found in the folder!"
-        xml_filepath = xml_files[0]
-
-        xml_root = et.parse(str(xml_filepath)).getroot()
+        xml_file_path = handle_xml_file_path(folder_path=folder_path, initial_xml_file_path=xml_file_path)
+        xml_root = et.parse(str(xml_file_path)).getroot()
         self._sampling_frequency = float(xml_root.find('acquisitionSystem').find('samplingRate').text)
 
         res_files = get_shank_files(folder_path=folder_path, suffix=".res")
@@ -607,7 +610,8 @@ class NeuroscopeMultiSortingExtractor(MultiSortingExtractor):
             nse_args = dict(
                 resfile_path=folder_path / f"{sorting_name}.res.{shank_id}",
                 clufile_path=folder_path / f"{sorting_name}.clu.{shank_id}",
-                keep_mua_units=keep_mua_units
+                keep_mua_units=keep_mua_units,
+                xml_file_path=xml_file_path,
             )
 
             if load_waveforms:
